#package for basic maths

This is a simple package. It has a few mathematical functions. It also has a Linear Regression model for one feature and output. 
You can use [Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

